===================
Askbot - Q&A forum
===================

This is Askbot project - open source Q&A system, like StackOverflow, Yahoo Answers and some others

Demo site is http://askbot.org

All documentation is in the directory askbot/doc

askbot-devel repository is open to anyone who wants to help develop Askbot - just drop us a note

Askbot is based on code of CNPROG, originally created by Mike Chen 
and Sailing Cai and some code written for OSQA
